package log

import (
	"sync"

	"codeberg.org/gruf/go-byteutil"
)

// bufPool is a global pool of log format buffers.
var bufPool = sync.Pool{
	New: func() interface{} {
		b := make([]byte, 0, 512)
		return &byteutil.Buffer{B: b}
	},
}

// getBuf will acquire a buffer from pool.
func getBuf() *byteutil.Buffer {
	return bufPool.Get().(*byteutil.Buffer)
}

// putBuf will reset and place buffer in pool.
func putBuf(buf *byteutil.Buffer) {
	if buf.Cap() > int(^uint16(0)) {
		return // drop large buffers
	}
	buf.Reset()
	bufPool.Put(buf)
}
